@@ -54,8 +54,8 @@ def main():
     """
     main_window = MainWindow()
     logger = logging.getLogger()
+    logger.setLevel(logging.DEBUG)
     logging_win_handler = LoggingHandler(main_window)  # instantiate a handler that sends log records to GUI
     logger.addHandler(logging_win_handler)
-    logger.setLevel(logging.DEBUG)  # sends log records to stdout
     main_window.logging_win_handler = logging_win_handler
     main_window.mainloop()
